FeedElement class

Constructors

FeedElement({required String id, required String name, required String? devName, required String link, required String? icon, required String? smallDescription, required String? smallDescriptionHTML, required List<Action> actions})
FeedElement.fromJson(Map<String, dynamic> json)
factory

Properties

actions → List<Action>
final
devName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
final
id → String
final
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smallDescription → String?
final
smallDescriptionHTML → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited