OfferWallRequest class

Constructors

OfferWallRequest({required String userId, String? zipCode, String? countryCode, int? userAge, UserGender? userGender, DateTime? userSignupDate, List<String>? callbackParameters})

Properties

callbackParameters → List<String>?
parameters you wish to get back in your callback
final
countryCode → String?
Current 2 letters country code of the user, if not provided will default to the user's preferred region
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAge → int?
Your user's age
final
userGender → UserGender?
Gender of the user, to access targetted campaigns
final
userId → String
Your unique id for the current user - the only required parameter
final
userSignupDate → DateTime?
Date at which your user did signup
final
zipCode → String?
Current zipCode of the user, should be fetched from geolocation, not from geoip
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited